---
meta:
    title: Border Radius
    description: Border radius tokens are used to give sharp edges a more subtle, rounded effect.
---

# Border Radius Tokens

Border radius tokens are used to give sharp edges a more subtle, rounded effect. They use rem units so they scale with the base font size. The pixel values displayed are based on a 16px font size.

| Token                           | Value          | Example                                                                                           |
| ------------------------------- | -------------- | ------------------------------------------------------------------------------------------------- |
| `--terra-border-radius-small`   | 0.125rem (2px) | <div class="border-radius-demo" style="border-radius: var(--terra-border-radius-small);"></div>   |
| `--terra-border-radius-medium`  | 0.25rem (4px)  | <div class="border-radius-demo" style="border-radius: var(--terra-border-radius-medium);"></div>  |
| `--terra-border-radius-large`   | 0.5rem (8px)   | <div class="border-radius-demo" style="border-radius: var(--terra-border-radius-large);"></div>   |
| `--terra-border-radius-x-large` | 1rem (16px)    | <div class="border-radius-demo" style="border-radius: var(--terra-border-radius-x-large);"></div> |
| `--terra-border-radius-circle`  | 50%            | <div class="border-radius-demo" style="border-radius: var(--terra-border-radius-circle);"></div>  |
